@@ -15,7 +15,7 @@ from argparse import ArgumentParser
 from pathlib import Path
 from python import apogee_data
 
-__version__ = '3.2.0'
+__version__ = '3.2.1'
 
 
 class ApogeeFlat:
@@ -31,9 +31,15 @@ class ApogeeFlat:
     def run_inputs(self):
         for i, sjd in enumerate(self.args.sjds):
             for exp in self.args.exps[i]:
-                ap_img = apogee_data.APOGEERaw('/data/apogee/archive/{}/apR-a'
-                                               '-{}.apz'.format(
-                                                   sjd, exp), self.args)
+                try:
+                    ap_img = apogee_data.APOGEERaw('/data/apogee/archive/{}/'
+                                                   'apR-a-{}.apz'.format(
+                        sjd, exp), self.args)
+                except OSError:
+                    ap_img = apogee_data.APOGEERaw(
+                        (Path.home() / ('data/apogee/archive/{}/apR-a-{}.apz'
+                                        ''.format(sjd, exp))).as_posix(),
+                        self.args)
                 ap_img.ap_test((900, 910), master_col=self.ap_master,
                                plot=self.args.plot)
 
@@ -75,7 +81,7 @@ def parse_args():
 
 def main():
     args = parse_args()
-    master_path = (Path(__file__).absolute().parent.parent
+    master_path = (Path(apogee_data.__file__).absolute().parent.parent
                    / 'dat/master_dome_flat_1.npy')
     master_data = np.load(master_path)
 
